import { Component, Input, OnInit } from '@angular/core';
import { NgxChartsModule } from '@swimlane/ngx-charts';
import { PengukuranService } from '../../services/pengukuran.service';
import { Storage } from '@ionic/storage-angular';

@Component({
  selector: 'app-line-chart',
  templateUrl: './line-chart.component.html',
  styleUrls: ['./line-chart.component.scss'],
  standalone: true,
  imports: [NgxChartsModule],
})
export class LineChartComponent implements OnInit {

  // options
  legend: boolean = true;
  showLabels: boolean = true;
  animations: boolean = true;
  xAxis: boolean = true;
  yAxis: boolean = true;
  showYAxisLabel: boolean = true;
  showXAxisLabel: boolean = true;
  xAxisLabel: string = 'INDIKATOR KESEHATAN INDIVIDU';
  yAxisLabel: string = 'Berat Badan';
  timeline: boolean = true;
  multi: any[] = [];
  @Input() view: any;
  colorScheme: any = {
    domain: ['#5AA454', '#E44D25', '#CFC0BB', '#7aa3e5', '#a8385d', '#aae3f5']
  };

  constructor(
    private pengukuranService: PengukuranService,
    private storage: Storage,) { }

  async ngOnInit() {
    await this.storage.create();
    this.getDataGraph()
    // this.generateData();
  }
  async getDataGraph() {
    const id_identitas = await this.storage.get('id_identitas');
    this.pengukuranService.getGraphByIdentitas(id_identitas).subscribe(
      async (response: any[]) => {
        console.log(response);

        // Filter the response to include only the segment with the name "Berat Badan"
        const filteredResponse = response.filter(series => series.series_name === "Berat Badan");

        // Transform the filtered response into the desired format
        this.multi = filteredResponse.map(series => ({
          name: series.series_name,
          series: series.series_data.map((value: any, index: number) => ({
            name: (index + 1).toString(), // Use index + 1 as the name
            value: value
          }))
        }));
      },
      error => {
        console.error('Error fetching data:', error);
      }
    );
  }
  private getDateByIndex(index: number): string {
    // Define a method to generate date strings based on index
    // For demonstration, we use a fixed start date and increment it by one day for each index
    const startDate = new Date('2024-01-01');
    const date = new Date(startDate);
    date.setDate(startDate.getDate() + index);

    return date.toISOString().split('T')[0]; // Format date as 'YYYY-MM-DD'
  }
  onSelect(data: any): void {
    console.log('Item clicked', JSON.parse(JSON.stringify(data)));
  }

  onActivate(data: any): void {
    console.log('Activate', JSON.parse(JSON.stringify(data)));
  }

  onDeactivate(data: any): void {
    console.log('Deactivate', JSON.parse(JSON.stringify(data)));
  }
}
