import { Component, OnInit, ChangeDetectorRef } from '@angular/core';
import { Platform } from '@ionic/angular';
import { CommonModule } from '@angular/common';
import {
  IonHeader,
  IonToolbar,
  IonTitle,
  IonContent,
  IonCard,
  IonCardTitle,
  IonCardContent,
  IonButtons, 
  IonMenuButton,
} from '@ionic/angular/standalone';
import { NgClass } from '@angular/common';
import { Chart, registerables } from 'chart.js';
import { BaseChartDirective } from 'ng2-charts';
import { PengukuranService } from '../services/pengukuran.service';
import { Storage } from '@ionic/storage-angular';


Chart.register(...registerables);
@Component({
  selector: 'app-indikator',
  templateUrl: './indikator.page.html',
  styleUrls: ['./indikator.page.scss'],
  standalone: true,
  imports: [
    CommonModule,
    IonButtons,
    IonMenuButton,
    IonHeader,
    IonToolbar,
    IonTitle,
    IonContent,
    IonCard,
    IonCardTitle,
    IonCardContent,
    NgClass,
    BaseChartDirective
  ],
})
export class IndikatorPage implements OnInit {
  public seriesData: any[] = [];

  constructor(
    private pengukuranService: PengukuranService,
    private storage: Storage,
    private cdr: ChangeDetectorRef
  ) {}

  async ngOnInit() {
    await this.storage.create();
    this.getDataGraph();
  }

  async getDataGraph() {
    const id_identitas = await this.storage.get('id_identitas');
    this.pengukuranService.getGraphByIdentitas(id_identitas).subscribe(
      (response: any[]) => {
        this.seriesData = response;
        this.cdr.detectChanges();
        this.seriesData.forEach((series, index) => this.createChart(series, index));
      },
      error => {
        console.error('Error fetching data:', error);
      }
    );
  }

  createChart(series: { series_name: any; series_data: any; }, index: number) {
    const canvas = document.getElementById(`chart-${index}`) as HTMLCanvasElement;
    const ctx = canvas.getContext('2d');
    const labels = series.series_data.map((_: any, i: number) => (i + 1).toString());
    if (ctx) {
      const gradient = ctx.createLinearGradient(0, 0, 0, 400);
      gradient.addColorStop(0, 'rgba(0, 255, 0, 0.5)'); // Green
      gradient.addColorStop(0.33, 'rgba(255, 255, 0, 0.5)'); // Yellow
      gradient.addColorStop(0.66, 'rgba(255, 0, 0, 0.5)'); // Red

      new Chart(ctx, {
        type: 'line',
        data: {
          labels: labels,
          datasets: [{
            label: series.series_name,
            data: series.series_data,
            borderColor: 'black',
            fill: true,
          }]
        },
        options: {
          responsive: true,
          scales: {
            y: {
              min: 0,
              max: 3,
              beginAtZero: true,
              ticks: {
                stepSize: 1,
                callback: function(value) {
                  return value;
                }
              }
            }
          }
        },
        plugins: [{
          beforeDraw: function (chart) {
            const ctx = chart.ctx;
            const chartArea = chart.chartArea;
            const chartHeight = chartArea.bottom - chartArea.top;
            const greenStop = chartHeight * 0.33;
            const yellowStop = chartHeight * 0.66;

            const gradient = ctx.createLinearGradient(0, chartArea.top, 0, chartArea.bottom);
            gradient.addColorStop(0, 'rgba(0, 255, 0, 0.5)');
            gradient.addColorStop(greenStop / chartHeight, 'rgba(0, 255, 0, 0.5)');
            gradient.addColorStop(greenStop / chartHeight, 'rgba(255, 255, 0, 0.5)');
            gradient.addColorStop(yellowStop / chartHeight, 'rgba(255, 255, 0, 0.5)');
            gradient.addColorStop(yellowStop / chartHeight, 'rgba(255, 0, 0, 0.5)');
            gradient.addColorStop(1, 'rgba(255, 0, 0, 0.5)');

            ctx.save();
            ctx.fillStyle = gradient;
            ctx.fillRect(chartArea.left, chartArea.top, chartArea.right - chartArea.left, chartArea.bottom - chartArea.top);
            ctx.restore();
          },
          id: ''
        }]
      });
    }
  }
}