import { Component, OnInit, ViewChild } from '@angular/core';
import {
  IonHeader,
  IonToolbar,
  IonTitle,
  IonContent,
  IonGrid,
  IonRow,
  IonCol,
  IonCard,
  IonButton,
  IonInput,
  IonButtons, 
  IonMenuButton,
} from '@ionic/angular/standalone';
import { ColumnMode, DatatableComponent, NgxDatatableModule } from '@swimlane/ngx-datatable';
import { PengukuranService } from '../services/pengukuran.service';
import { Storage } from '@ionic/storage-angular';
import { CustomDateModule } from './custom-date.module'; 

@Component({
  selector: 'app-tabel',
  templateUrl: './tabel.page.html',
  styleUrls: ['./tabel.page.scss'],
  standalone: true,
  imports: [
    IonHeader,
    IonToolbar,
    IonTitle,
    IonContent,
    IonGrid,
    IonRow,
    IonCol,
    IonCard,
    IonButton,
    IonInput,
    NgxDatatableModule,
    IonButtons,
    IonMenuButton,
    CustomDateModule
  ],
})
export class TabelPage implements OnInit {

  @ViewChild(DatatableComponent) table!: DatatableComponent;
  ColumnMode = ColumnMode;
  loadingIndicator!: boolean;
  temp: any[] = [];
  rows: any[] = [];
  dummy: any;
  

  constructor(private pengukuranService: PengukuranService, private storage: Storage,) { }

  async ngOnInit() {
    await this.storage.create();
    this.getPengukuranData();
  
  }
  async getPengukuranData() {
    this.loadingIndicator = true;
    const idIdentitas = await this.storage.get('id_identitas');
    this.pengukuranService.getPengukuranByIdentitasId(idIdentitas).subscribe(
      (res: any) => {
        console.log('Data Pengukuran:', res);
        this.rows = [...res.data];
      },
      (error: any) => {
        console.error('Error:', error);
      }
    );
    this.loadingIndicator = false;
  } 
}